---
name: Issue
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

- The program crashes?
- The program stopped working?
- Have a feature request?

Please ask on https://tatsumoto.neocities.org/blog/join-our-community.html instead.
It is easier for our community members to provide support over in the chats. Thank you!

Don't forget to provide the following information:

**Environment**

1) OS name  [e.g. Parabola, Debian]
2) OS version
3) Python version
3) Anki version
4) Logs
5) Screenshots, if applicable

**Describe the bug**
A description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1) Press x '...'
2) Click on '....'
3) See error

**Expected behavior**
A description of what you expected to happen.
